function [bvp,info]=setBVPStationaryConvectionDiffusion2D01(N,varargin)
  [default_geodir,default_meshdir]=fc_vfemp1.default_directories(2);
  p = inputParser; 
  p.addParameter('verbose',0,@isscalar); 
  p.addParamValue('geodir',default_geodir,@ischar); 
  p.addParamValue('meshdir',default_meshdir,@ischar);
  p.parse(varargin{:});
  R=p.Results;
  geofile='disk3holes';  
  af=@(x,y) 0.1+y.^2;
  Vx=@(x,y) -10*y;Vy=@(x,y) 10*x;
  b=0.01;g2=4;g4=-4;
  f=@(x,y) -200.0*exp(-((x-0.75).^2+y.^2)/(0.1));
  if R.verbose>=1
     fprintf('------------------------------------------------------\n'); 
    fprintf('      2D stationary convection-diffusion BVP\n');
    fprintf('         on GMSH mesh from %s.geo\n',geofile);
    fprintf('               - div(a grad u) + <V,grad u> + b u = f\n')
    fprintf(' and boundary conditions :\n');
    fprintf('   * Dirichlet on [2,4,20,21]\n');
    fprintf('       u = 4 on [2], -4 on [4] and 0 on [20,21]  \n');
    fprintf('   * Neumann on [1,3,10]\n');
    fprintf('       du/dn = 0 on [2,3,10]\n');
    fprintf(' with \n');
    fprintf('   a = %s \n',func2str(af));
    fprintf('   V = [%s,%s] \n',func2str(Vx),func2str(Vy));
    fprintf('   b = %g \n',b);
    fprintf('   f = %s \n',func2str(f));
    fprintf('------------------------------------------------------\n');
    if R.verbose==10, return;end
  end

  if R.verbose>=2,fprintf('1. Building the mesh using GMSH\n');end
  tstart=tic();
  meshfile=gmsh.buildmesh2d(geofile,N,'geodir',R.geodir,'meshdir',R.meshdir);%,'force',true);
  
  Th=siMesh(meshfile);
  
  tcpu(1)=toc(tstart);
  if R.verbose>=2
    fprintf('     Mesh sizes : nq=%d, nme=%d, h=%.3e\n',Th.nq,Th.get_nme(),Th.get_h());
    fprintf('2. Setting 2D stationary convection-diffusion BVP\n');
  end
  tstart=tic();
  Lop=Loperator(Th.dim,Th.d,{af,[];[],af},[],{Vx,Vy},b);
  pde=PDEelt(Lop,f);
  bvp=BVP(Th,pde);
  bvp.setDirichlet(2, g2);
  bvp.setDirichlet(4, g4);
  bvp.setDirichlet(20, 0.);
  bvp.setDirichlet(21, 0.);
  tcpu(2)=toc(tstart);

  info.solex=[];
  info.V={Vx,Vy};
  info.f=f;
  info.tcpu=tcpu;
end